pub struct NeuralNetwork {
pub learning_rate: f32,
pub layer_sizes: Vec<u32>,
pub weights: Vec<Matrix>,
pub biases: Vec<Matrix>,
pub command_receiver: Option<Receiver<NNCommand>>,
pub command_sender: Option<Sender<NNCommand>>,
pub update_interval: usize,
}Expand description
A Neural Network, use this one for training and the other one for predicting
Fields
learning_rate: f32layer_sizes: Vec<u32>weights: Vec<Matrix>biases: Vec<Matrix>command_receiver: Option<Receiver<NNCommand>>command_sender: Option<Sender<NNCommand>>update_interval: usizeImplementations
Sourceimpl NeuralNetwork
impl NeuralNetwork
pub fn new(layer_sizes: Vec<u32>) -> NeuralNetwork
Sourcepub fn train_batches(
&mut self,
input: Vec<Vec<f32>>,
target: Vec<Vec<f32>>,
batch_number: usize,
) -> usize
pub fn train_batches( &mut self, input: Vec<Vec<f32>>, target: Vec<Vec<f32>>, batch_number: usize, ) -> usize
One Epoch: Create a batch of n neural networks, and divide the training data for those n networks Let them train and then average the weights and biases of the networks Return the averaged weights and biases and then average the weights and bias correction over all the networks and apply them to the neural network Run each batch in a thread Returns the amount of correct predictions
Sourcepub fn train_epochs(
&mut self,
input: Vec<Vec<f32>>,
target: Vec<Vec<f32>>,
batch_number: usize,
epochs: usize,
)
pub fn train_epochs( &mut self, input: Vec<Vec<f32>>, target: Vec<Vec<f32>>, batch_number: usize, epochs: usize, )
Train the neural network with the given input and target for x epochs
Sourcepub fn save_weights_biases(&self, file_name: String)
pub fn save_weights_biases(&self, file_name: String)
Save weights and biases to a file in the current directory called
Sourcepub fn load_from_save(path: &str) -> Self
pub fn load_from_save(path: &str) -> Self
Load weights and biases from a file in the current directory todo: tests this